static PyObject* DictIds = NULL;
static void _init_dict_ids(void)
{
  DictIds = PyDict_New();

  PyDict_SetItemString(DictIds, "symchi", Py_BuildValue("ii", AB7_INVARS_SYMCHI, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pvelmax", Py_BuildValue("ii", AB7_INVARS_PVELMAX, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "ph_freez_disp_option", Py_BuildValue("ii", AB7_INVARS_PH_FREEZ_DISP_OPTION, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "slk_rankpp", Py_BuildValue("ii", AB7_INVARS_SLK_RANKPP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_interp_rl_nb", Py_BuildValue("ii", AB7_INVARS_BS_INTERP_RL_NB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "slabwsrad", Py_BuildValue("ii", AB7_INVARS_SLABWSRAD, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "rfstrs", Py_BuildValue("ii", AB7_INVARS_RFSTRS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "exchn2n3d", Py_BuildValue("ii", AB7_INVARS_EXCHN2N3D, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert3_elfd", Py_BuildValue("ii", AB7_INVARS_D3E_PERT3_ELFD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmftqmc_n", Py_BuildValue("ii", AB7_INVARS_DMFTQMC_N, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "wvl_nprccg", Py_BuildValue("ii", AB7_INVARS_WVL_NPRCCG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getddb", Py_BuildValue("ii", AB7_INVARS_GETDDB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwgamma", Py_BuildValue("ii", AB7_INVARS_GWGAMMA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_ngpts", Py_BuildValue("ii", AB7_INVARS_VDW_DF_NGPTS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ddb_ngqpt", Py_BuildValue("ii", AB7_INVARS_DDB_NGQPT, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "gw_toldfeig", Py_BuildValue("ii", AB7_INVARS_GW_TOLDFEIG, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "useexexch", Py_BuildValue("ii", AB7_INVARS_USEEXEXCH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tolmxf", Py_BuildValue("ii", AB7_INVARS_TOLMXF, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "lotf_version", Py_BuildValue("ii", AB7_INVARS_LOTF_VERSION, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "efmas_n_dirs", Py_BuildValue("ii", AB7_INVARS_EFMAS_N_DIRS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "cd_frqim_method", Py_BuildValue("ii", AB7_INVARS_CD_FRQIM_METHOD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prt1dm", Py_BuildValue("ii", AB7_INVARS_PRT1DM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "usepotzero", Py_BuildValue("ii", AB7_INVARS_USEPOTZERO, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prepanl", Py_BuildValue("ii", AB7_INVARS_PREPANL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_kmax_analytic", Py_BuildValue("ii", AB7_INVARS_GWLS_KMAX_ANALYTIC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nspinor", Py_BuildValue("ii", AB7_INVARS_NSPINOR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "rfatpol", Py_BuildValue("ii", AB7_INVARS_RFATPOL, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "dmftctqmc_gmove", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_GMOVE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ndtset", Py_BuildValue("ii", AB7_INVARS_NDTSET, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "usepawu", Py_BuildValue("ii", AB7_INVARS_USEPAWU, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mpw", Py_BuildValue("ii", AB7_INVARS_MPW, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nfreqre", Py_BuildValue("ii", AB7_INVARS_NFREQRE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawcross", Py_BuildValue("ii", AB7_INVARS_PAWCROSS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "occopt", Py_BuildValue("ii", AB7_INVARS_OCCOPT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getddk", Py_BuildValue("ii", AB7_INVARS_GETDDK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "imgmov", Py_BuildValue("ii", AB7_INVARS_IMGMOV, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "postoldff", Py_BuildValue("ii", AB7_INVARS_POSTOLDFF, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_tolerance", Py_BuildValue("ii", AB7_INVARS_VDW_DF_TOLERANCE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "postoldfe", Py_BuildValue("ii", AB7_INVARS_POSTOLDFE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "boxcenter", Py_BuildValue("ii", AB7_INVARS_BOXCENTER, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "builtintest", Py_BuildValue("ii", AB7_INVARS_BUILTINTEST, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tolmxde", Py_BuildValue("ii", AB7_INVARS_TOLMXDE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "bxctmindg", Py_BuildValue("ii", AB7_INVARS_BXCTMINDG, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "qptdm", Py_BuildValue("ii", AB7_INVARS_QPTDM, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "td_mexcit", Py_BuildValue("ii", AB7_INVARS_TD_MEXCIT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ga_fitness", Py_BuildValue("ii", AB7_INVARS_GA_FITNESS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nctime", Py_BuildValue("ii", AB7_INVARS_NCTIME, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "frzfermi", Py_BuildValue("ii", AB7_INVARS_FRZFERMI, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "hyb_mixing", Py_BuildValue("ii", AB7_INVARS_HYB_MIXING, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "rfphon", Py_BuildValue("ii", AB7_INVARS_RFPHON, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "plowan_bandi", Py_BuildValue("ii", AB7_INVARS_PLOWAN_BANDI, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtden", Py_BuildValue("ii", AB7_INVARS_PRTDEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwpara", Py_BuildValue("ii", AB7_INVARS_GWPARA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdbsreso", Py_BuildValue("ii", AB7_INVARS_IRDBSRESO, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "recptrott", Py_BuildValue("ii", AB7_INVARS_RECPTROTT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "red_efieldbar", Py_BuildValue("ii", AB7_INVARS_RED_EFIELDBAR, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "jdtset", Py_BuildValue("ii", AB7_INVARS_JDTSET, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_haydock_niter", Py_BuildValue("ii", AB7_INVARS_BS_HAYDOCK_NITER, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmftqmc_l", Py_BuildValue("ii", AB7_INVARS_DMFTQMC_L, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mep_solver", Py_BuildValue("ii", AB7_INVARS_MEP_SOLVER, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nstep", Py_BuildValue("ii", AB7_INVARS_NSTEP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "iomode", Py_BuildValue("ii", AB7_INVARS_IOMODE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtgsr", Py_BuildValue("ii", AB7_INVARS_PRTGSR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "use_gpu_cuda", Py_BuildValue("ii", AB7_INVARS_USE_GPU_CUDA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "algalch", Py_BuildValue("ii", AB7_INVARS_ALGALCH, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "use_gemm_nonlop", Py_BuildValue("ii", AB7_INVARS_USE_GEMM_NONLOP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nc_xccc_gspace", Py_BuildValue("ii", AB7_INVARS_NC_XCCC_GSPACE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "kptrlatt", Py_BuildValue("ii", AB7_INVARS_KPTRLATT, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "bs_algorithm", Py_BuildValue("ii", AB7_INVARS_BS_ALGORITHM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwmem", Py_BuildValue("ii", AB7_INVARS_GWMEM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nloalg", Py_BuildValue("ii", AB7_INVARS_NLOALG, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "npkpt", Py_BuildValue("ii", AB7_INVARS_NPKPT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gpu_devices", Py_BuildValue("ii", AB7_INVARS_GPU_DEVICES, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "prtxml", Py_BuildValue("ii", AB7_INVARS_PRTXML, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "usekden", Py_BuildValue("ii", AB7_INVARS_USEKDEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nppert", Py_BuildValue("ii", AB7_INVARS_NPPERT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "xred_orig", Py_BuildValue("ii", AB7_INVARS_XRED_ORIG, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "gwls_band_index", Py_BuildValue("ii", AB7_INVARS_GWLS_BAND_INDEX, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ph_nqpath", Py_BuildValue("ii", AB7_INVARS_PH_NQPATH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "kptns", Py_BuildValue("ii", AB7_INVARS_KPTNS, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "nberry", Py_BuildValue("ii", AB7_INVARS_NBERRY, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "chksymbreak", Py_BuildValue("ii", AB7_INVARS_CHKSYMBREAK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "freqremin", Py_BuildValue("ii", AB7_INVARS_FREQREMIN, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "mgfftdg", Py_BuildValue("ii", AB7_INVARS_MGFFTDG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "exchmix", Py_BuildValue("ii", AB7_INVARS_EXCHMIX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert3_atpol", Py_BuildValue("ii", AB7_INVARS_D3E_PERT3_ATPOL, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "tfkinfunc", Py_BuildValue("ii", AB7_INVARS_TFKINFUNC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ptcharge", Py_BuildValue("ii", AB7_INVARS_PTCHARGE, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "kptnrm", Py_BuildValue("ii", AB7_INVARS_KPTNRM, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "irdbseig", Py_BuildValue("ii", AB7_INVARS_IRDBSEIG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "slabzbeg", Py_BuildValue("ii", AB7_INVARS_SLABZBEG, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "gw_customnfreqsp", Py_BuildValue("ii", AB7_INVARS_GW_CUSTOMNFREQSP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "red_efield", Py_BuildValue("ii", AB7_INVARS_RED_EFIELD, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "gw_sctype", Py_BuildValue("ii", AB7_INVARS_GW_SCTYPE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_interp_kmult", Py_BuildValue("ii", AB7_INVARS_BS_INTERP_KMULT, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "gwls_diel_model", Py_BuildValue("ii", AB7_INVARS_GWLS_DIEL_MODEL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vis", Py_BuildValue("ii", AB7_INVARS_VIS, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "cd_imfrqs", Py_BuildValue("ii", AB7_INVARS_CD_IMFRQS, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "userre", Py_BuildValue("ii", AB7_INVARS_USERRE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "dmftctqmc_correl", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_CORREL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtwf_full", Py_BuildValue("ii", AB7_INVARS_PRTWF_FULL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "npwwfn", Py_BuildValue("ii", AB7_INVARS_NPWWFN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "efmas_ntheta", Py_BuildValue("ii", AB7_INVARS_EFMAS_NTHETA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tim1rev", Py_BuildValue("ii", AB7_INVARS_TIM1REV, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mffmem", Py_BuildValue("ii", AB7_INVARS_MFFMEM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "charge", Py_BuildValue("ii", AB7_INVARS_CHARGE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "dfield", Py_BuildValue("ii", AB7_INVARS_DFIELD, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "dmftctqmc_grnns", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_GRNNS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_exchange_term", Py_BuildValue("ii", AB7_INVARS_BS_EXCHANGE_TERM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "imgwfstor", Py_BuildValue("ii", AB7_INVARS_IMGWFSTOR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getwfkfine", Py_BuildValue("ii", AB7_INVARS_GETWFKFINE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "eph_task", Py_BuildValue("ii", AB7_INVARS_EPH_TASK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mk1mem", Py_BuildValue("ii", AB7_INVARS_MK1MEM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "hyb_range_fock", Py_BuildValue("ii", AB7_INVARS_HYB_RANGE_FOCK, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_damin", Py_BuildValue("ii", AB7_INVARS_VDW_DF_DAMIN, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert2_dir", Py_BuildValue("ii", AB7_INVARS_D3E_PERT2_DIR, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "prtkpt", Py_BuildValue("ii", AB7_INVARS_PRTKPT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "freqim_alpha", Py_BuildValue("ii", AB7_INVARS_FREQIM_ALPHA, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_dcut", Py_BuildValue("ii", AB7_INVARS_VDW_DF_DCUT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "npfft", Py_BuildValue("ii", AB7_INVARS_NPFFT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtvclmb", Py_BuildValue("ii", AB7_INVARS_PRTVCLMB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "qmass", Py_BuildValue("ii", AB7_INVARS_QMASS, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "rf2_pert2_dir", Py_BuildValue("ii", AB7_INVARS_RF2_PERT2_DIR, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "ecutsigx", Py_BuildValue("ii", AB7_INVARS_ECUTSIGX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ga_opt_percent", Py_BuildValue("ii", AB7_INVARS_GA_OPT_PERCENT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "polcen", Py_BuildValue("ii", AB7_INVARS_POLCEN, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "recrcut", Py_BuildValue("ii", AB7_INVARS_RECRCUT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "wvl_hgrid", Py_BuildValue("ii", AB7_INVARS_WVL_HGRID, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "userec", Py_BuildValue("ii", AB7_INVARS_USEREC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtefmas", Py_BuildValue("ii", AB7_INVARS_PRTEFMAS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "spmeth", Py_BuildValue("ii", AB7_INVARS_SPMETH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "npvel", Py_BuildValue("ii", AB7_INVARS_NPVEL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mkmem", Py_BuildValue("ii", AB7_INVARS_MKMEM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "qprtrb", Py_BuildValue("ii", AB7_INVARS_QPRTRB, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "gwls_npt_gauss_quad", Py_BuildValue("ii", AB7_INVARS_GWLS_NPT_GAUSS_QUAD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "cineb_start", Py_BuildValue("ii", AB7_INVARS_CINEB_START, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getden", Py_BuildValue("ii", AB7_INVARS_GETDEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "auxc_scal", Py_BuildValue("ii", AB7_INVARS_AUXC_SCAL, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "recefermi", Py_BuildValue("ii", AB7_INVARS_RECEFERMI, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "getxcart", Py_BuildValue("ii", AB7_INVARS_GETXCART, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdpawden", Py_BuildValue("ii", AB7_INVARS_IRDPAWDEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "plowan_iatom", Py_BuildValue("ii", AB7_INVARS_PLOWAN_IATOM, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "vacwidth", Py_BuildValue("ii", AB7_INVARS_VACWIDTH, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "eph_ngqpt_fine", Py_BuildValue("ii", AB7_INVARS_EPH_NGQPT_FINE, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "usedmatpu", Py_BuildValue("ii", AB7_INVARS_USEDMATPU, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "td_maxene", Py_BuildValue("ii", AB7_INVARS_TD_MAXENE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "fockdownsampling", Py_BuildValue("ii", AB7_INVARS_FOCKDOWNSAMPLING, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "gw_invalid_freq", Py_BuildValue("ii", AB7_INVARS_GW_INVALID_FREQ, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "paral_kgb", Py_BuildValue("ii", AB7_INVARS_PARAL_KGB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "string_algo", Py_BuildValue("ii", AB7_INVARS_STRING_ALGO, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "adpimd", Py_BuildValue("ii", AB7_INVARS_ADPIMD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "get1wf", Py_BuildValue("ii", AB7_INVARS_GET1WF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdden", Py_BuildValue("ii", AB7_INVARS_IRDDEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "zcut", Py_BuildValue("ii", AB7_INVARS_ZCUT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "getbseig", Py_BuildValue("ii", AB7_INVARS_GETBSEIG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getxred", Py_BuildValue("ii", AB7_INVARS_GETXRED, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bmass", Py_BuildValue("ii", AB7_INVARS_BMASS, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_kmax_poles", Py_BuildValue("ii", AB7_INVARS_GWLS_KMAX_POLES, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "w90prtunk", Py_BuildValue("ii", AB7_INVARS_W90PRTUNK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmftctqmc_mrka", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_MRKA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "plowan_compute", Py_BuildValue("ii", AB7_INVARS_PLOWAN_COMPUTE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "typat", Py_BuildValue("ii", AB7_INVARS_TYPAT, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "ratsph", Py_BuildValue("ii", AB7_INVARS_RATSPH, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "icutcoul", Py_BuildValue("ii", AB7_INVARS_ICUTCOUL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mep_mxstep", Py_BuildValue("ii", AB7_INVARS_MEP_MXSTEP, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "prtspcur", Py_BuildValue("ii", AB7_INVARS_PRTSPCUR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "useylm", Py_BuildValue("ii", AB7_INVARS_USEYLM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "macro_uj", Py_BuildValue("ii", AB7_INVARS_MACRO_UJ, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmft_rslf", Py_BuildValue("ii", AB7_INVARS_DMFT_RSLF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "npimage", Py_BuildValue("ii", AB7_INVARS_NPIMAGE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getcell", Py_BuildValue("ii", AB7_INVARS_GETCELL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "max_ncpus", Py_BuildValue("ii", AB7_INVARS_MAX_NCPUS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "maxnsym", Py_BuildValue("ii", AB7_INVARS_MAXNSYM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tolsym", Py_BuildValue("ii", AB7_INVARS_TOLSYM, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "rectolden", Py_BuildValue("ii", AB7_INVARS_RECTOLDEN, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "kssform", Py_BuildValue("ii", AB7_INVARS_KSSFORM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "userrd", Py_BuildValue("ii", AB7_INVARS_USERRD, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "userra", Py_BuildValue("ii", AB7_INVARS_USERRA, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "userrc", Py_BuildValue("ii", AB7_INVARS_USERRC, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ddamp", Py_BuildValue("ii", AB7_INVARS_DDAMP, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "effmass_free", Py_BuildValue("ii", AB7_INVARS_EFFMASS_FREE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "prtphbands", Py_BuildValue("ii", AB7_INVARS_PRTPHBANDS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert3_phon", Py_BuildValue("ii", AB7_INVARS_D3E_PERT3_PHON, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmft_mxsf", Py_BuildValue("ii", AB7_INVARS_DMFT_MXSF, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "wfoptalg", Py_BuildValue("ii", AB7_INVARS_WFOPTALG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tfw_toldfe", Py_BuildValue("ii", AB7_INVARS_TFW_TOLDFE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "vcutgeo", Py_BuildValue("ii", AB7_INVARS_VCUTGEO, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "tnons", Py_BuildValue("ii", AB7_INVARS_TNONS, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "efmas_dirs", Py_BuildValue("ii", AB7_INVARS_EFMAS_DIRS, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "vdw_df_threshold", Py_BuildValue("ii", AB7_INVARS_VDW_DF_THRESHOLD, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "irdwfk", Py_BuildValue("ii", AB7_INVARS_IRDWFK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ird1den", Py_BuildValue("ii", AB7_INVARS_IRD1DEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ntimimage", Py_BuildValue("ii", AB7_INVARS_NTIMIMAGE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawlcutd", Py_BuildValue("ii", AB7_INVARS_PAWLCUTD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nband", Py_BuildValue("ii", AB7_INVARS_NBAND, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "extrapwf", Py_BuildValue("ii", AB7_INVARS_EXTRAPWF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "wvl_crmult", Py_BuildValue("ii", AB7_INVARS_WVL_CRMULT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "dmftqmc_seed", Py_BuildValue("ii", AB7_INVARS_DMFTQMC_SEED, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "enunit", Py_BuildValue("ii", AB7_INVARS_ENUNIT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_nfrag", Py_BuildValue("ii", AB7_INVARS_VDW_NFRAG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtnest", Py_BuildValue("ii", AB7_INVARS_PRTNEST, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert2_phon", Py_BuildValue("ii", AB7_INVARS_D3E_PERT2_PHON, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdwfq", Py_BuildValue("ii", AB7_INVARS_IRDWFQ, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawstgylm", Py_BuildValue("ii", AB7_INVARS_PAWSTGYLM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "rf2_pert1_dir", Py_BuildValue("ii", AB7_INVARS_RF2_PERT1_DIR, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "iprcel", Py_BuildValue("ii", AB7_INVARS_IPRCEL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "iatfix", Py_BuildValue("ii", AB7_INVARS_IATFIX, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "dmftctqmc_meas", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_MEAS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "restartxf", Py_BuildValue("ii", AB7_INVARS_RESTARTXF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ph_ngqpt", Py_BuildValue("ii", AB7_INVARS_PH_NGQPT, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "irdddk", Py_BuildValue("ii", AB7_INVARS_IRDDDK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "spinmagntarget", Py_BuildValue("ii", AB7_INVARS_SPINMAGNTARGET, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "chempot", Py_BuildValue("ii", AB7_INVARS_CHEMPOT, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "prtpsps", Py_BuildValue("ii", AB7_INVARS_PRTPSPS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "autoparal", Py_BuildValue("ii", AB7_INVARS_AUTOPARAL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dynimage", Py_BuildValue("ii", AB7_INVARS_DYNIMAGE, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "spgroup", Py_BuildValue("ii", AB7_INVARS_SPGROUP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "npwsigx", Py_BuildValue("ii", AB7_INVARS_NPWSIGX, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vel_orig", Py_BuildValue("ii", AB7_INVARS_VEL_ORIG, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "nomegasf", Py_BuildValue("ii", AB7_INVARS_NOMEGASF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "iatsph", Py_BuildValue("ii", AB7_INVARS_IATSPH, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "pw_unbal_thresh", Py_BuildValue("ii", AB7_INVARS_PW_UNBAL_THRESH, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "nline", Py_BuildValue("ii", AB7_INVARS_NLINE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmftqmc_therm", Py_BuildValue("ii", AB7_INVARS_DMFTQMC_THERM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "kpt", Py_BuildValue("ii", AB7_INVARS_KPT, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "bdberry", Py_BuildValue("ii", AB7_INVARS_BDBERRY, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "rfmeth", Py_BuildValue("ii", AB7_INVARS_RFMETH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "useria", Py_BuildValue("ii", AB7_INVARS_USERIA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nfreqsp", Py_BuildValue("ii", AB7_INVARS_NFREQSP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "useric", Py_BuildValue("ii", AB7_INVARS_USERIC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "userid", Py_BuildValue("ii", AB7_INVARS_USERID, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "userie", Py_BuildValue("ii", AB7_INVARS_USERIE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "efmas_deg", Py_BuildValue("ii", AB7_INVARS_EFMAS_DEG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gw_freqsp", Py_BuildValue("ii", AB7_INVARS_GW_FREQSP, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "symafm", Py_BuildValue("ii", AB7_INVARS_SYMAFM, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "ntypalch", Py_BuildValue("ii", AB7_INVARS_NTYPALCH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "localrdwf", Py_BuildValue("ii", AB7_INVARS_LOCALRDWF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtdosm", Py_BuildValue("ii", AB7_INVARS_PRTDOSM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nonlinear_info", Py_BuildValue("ii", AB7_INVARS_NONLINEAR_INFO, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mdtemp", Py_BuildValue("ii", AB7_INVARS_MDTEMP, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "np_slk", Py_BuildValue("ii", AB7_INVARS_NP_SLK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "cd_halfway_freq", Py_BuildValue("ii", AB7_INVARS_CD_HALFWAY_FREQ, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "diemix", Py_BuildValue("ii", AB7_INVARS_DIEMIX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "lotf_nneigx", Py_BuildValue("ii", AB7_INVARS_LOTF_NNEIGX, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_nsmooth", Py_BuildValue("ii", AB7_INVARS_VDW_DF_NSMOOTH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "densty", Py_BuildValue("ii", AB7_INVARS_DENSTY, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "prtvpsp", Py_BuildValue("ii", AB7_INVARS_PRTVPSP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtebands", Py_BuildValue("ii", AB7_INVARS_PRTEBANDS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "maxestep", Py_BuildValue("ii", AB7_INVARS_MAXESTEP, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "efmas_calc_dirs", Py_BuildValue("ii", AB7_INVARS_EFMAS_CALC_DIRS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwencomp", Py_BuildValue("ii", AB7_INVARS_GWENCOMP, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "rectesteg", Py_BuildValue("ii", AB7_INVARS_RECTESTEG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtnabla", Py_BuildValue("ii", AB7_INVARS_PRTNABLA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ntypat", Py_BuildValue("ii", AB7_INVARS_NTYPAT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "icoulomb", Py_BuildValue("ii", AB7_INVARS_ICOULOMB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "iprcfc", Py_BuildValue("ii", AB7_INVARS_IPRCFC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nphf", Py_BuildValue("ii", AB7_INVARS_NPHF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "corecs", Py_BuildValue("ii", AB7_INVARS_CORECS, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "dmft_tollc", Py_BuildValue("ii", AB7_INVARS_DMFT_TOLLC, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "nimage", Py_BuildValue("ii", AB7_INVARS_NIMAGE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gethaydock", Py_BuildValue("ii", AB7_INVARS_GETHAYDOCK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "asr", Py_BuildValue("ii", AB7_INVARS_ASR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "eph_frohlichm", Py_BuildValue("ii", AB7_INVARS_EPH_FROHLICHM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmft_entropy", Py_BuildValue("ii", AB7_INVARS_DMFT_ENTROPY, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gw_nstep", Py_BuildValue("ii", AB7_INVARS_GW_NSTEP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "eph_extrael", Py_BuildValue("ii", AB7_INVARS_EPH_EXTRAEL, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ecutsm", Py_BuildValue("ii", AB7_INVARS_ECUTSM, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "eph_transport", Py_BuildValue("ii", AB7_INVARS_EPH_TRANSPORT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "freqremax", Py_BuildValue("ii", AB7_INVARS_FREQREMAX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "nbdbuf", Py_BuildValue("ii", AB7_INVARS_NBDBUF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "einterp", Py_BuildValue("ii", AB7_INVARS_EINTERP, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "natpawu", Py_BuildValue("ii", AB7_INVARS_NATPAWU, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dielam", Py_BuildValue("ii", AB7_INVARS_DIELAM, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "efield", Py_BuildValue("ii", AB7_INVARS_EFIELD, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "gw_frqim_inzgrid", Py_BuildValue("ii", AB7_INVARS_GW_FRQIM_INZGRID, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "iscf", Py_BuildValue("ii", AB7_INVARS_ISCF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bdeigrf", Py_BuildValue("ii", AB7_INVARS_BDEIGRF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawujat", Py_BuildValue("ii", AB7_INVARS_PAWUJAT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ixc", Py_BuildValue("ii", AB7_INVARS_IXC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "delayperm", Py_BuildValue("ii", AB7_INVARS_DELAYPERM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "xc_tb09_c", Py_BuildValue("ii", AB7_INVARS_XC_TB09_C, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "nscforder", Py_BuildValue("ii", AB7_INVARS_NSCFORDER, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawovlp", Py_BuildValue("ii", AB7_INVARS_PAWOVLP, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "plowan_it", Py_BuildValue("ii", AB7_INVARS_PLOWAN_IT, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "atvshift", Py_BuildValue("ii", AB7_INVARS_ATVSHIFT, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "prtpmp", Py_BuildValue("ii", AB7_INVARS_PRTPMP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "cpus", Py_BuildValue("ii", AB7_INVARS_CPUS, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_qcut", Py_BuildValue("ii", AB7_INVARS_VDW_DF_QCUT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ecuteps", Py_BuildValue("ii", AB7_INVARS_ECUTEPS, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "nzchempot", Py_BuildValue("ii", AB7_INVARS_NZCHEMPOT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gw_qlwl", Py_BuildValue("ii", AB7_INVARS_GW_QLWL, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "ph_ndivsm", Py_BuildValue("ii", AB7_INVARS_PH_NDIVSM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "plowan_lcalc", Py_BuildValue("ii", AB7_INVARS_PLOWAN_LCALC, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "irdbscoup", Py_BuildValue("ii", AB7_INVARS_IRDBSCOUP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_model_parameter", Py_BuildValue("ii", AB7_INVARS_GWLS_MODEL_PARAMETER, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "eph_mustar", Py_BuildValue("ii", AB7_INVARS_EPH_MUSTAR, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "genafm", Py_BuildValue("ii", AB7_INVARS_GENAFM, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "supercell_latt", Py_BuildValue("ii", AB7_INVARS_SUPERCELL_LATT, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "npspinor", Py_BuildValue("ii", AB7_INVARS_NPSPINOR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ngfftdg", Py_BuildValue("ii", AB7_INVARS_NGFFTDG, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "eph_fsmear", Py_BuildValue("ii", AB7_INVARS_EPH_FSMEAR, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "dmft_solv", Py_BuildValue("ii", AB7_INVARS_DMFT_SOLV, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prepgkk", Py_BuildValue("ii", AB7_INVARS_PREPGKK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ucrpa", Py_BuildValue("ii", AB7_INVARS_UCRPA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "cd_max_freq", Py_BuildValue("ii", AB7_INVARS_CD_MAX_FREQ, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "rprimd_orig", Py_BuildValue("ii", AB7_INVARS_RPRIMD_ORIG, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "prtvxc", Py_BuildValue("ii", AB7_INVARS_PRTVXC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nfftdg", Py_BuildValue("ii", AB7_INVARS_NFFTDG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "paral_rf", Py_BuildValue("ii", AB7_INVARS_PARAL_RF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_tol_3bt", Py_BuildValue("ii", AB7_INVARS_VDW_TOL_3BT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "istatimg", Py_BuildValue("ii", AB7_INVARS_ISTATIMG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_typfrag", Py_BuildValue("ii", AB7_INVARS_VDW_TYPFRAG, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "usefock", Py_BuildValue("ii", AB7_INVARS_USEFOCK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nbdblock", Py_BuildValue("ii", AB7_INVARS_NBDBLOCK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdwfkfine", Py_BuildValue("ii", AB7_INVARS_IRDWFKFINE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_tweaks", Py_BuildValue("ii", AB7_INVARS_VDW_DF_TWEAKS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdscr", Py_BuildValue("ii", AB7_INVARS_IRDSCR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "orbmag", Py_BuildValue("ii", AB7_INVARS_ORBMAG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_freq_mesh", Py_BuildValue("ii", AB7_INVARS_BS_FREQ_MESH, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "getgam_eig2nkq", Py_BuildValue("ii", AB7_INVARS_GETGAM_EIG2NKQ, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gw_frqre_inzgrid", Py_BuildValue("ii", AB7_INVARS_GW_FRQRE_INZGRID, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_first_seed", Py_BuildValue("ii", AB7_INVARS_GWLS_FIRST_SEED, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_tol", Py_BuildValue("ii", AB7_INVARS_VDW_TOL, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "use_slk", Py_BuildValue("ii", AB7_INVARS_USE_SLK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_rsoft", Py_BuildValue("ii", AB7_INVARS_VDW_DF_RSOFT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "lexexch", Py_BuildValue("ii", AB7_INVARS_LEXEXCH, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "rcut", Py_BuildValue("ii", AB7_INVARS_RCUT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "prtsuscep", Py_BuildValue("ii", AB7_INVARS_PRTSUSCEP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawsushat", Py_BuildValue("ii", AB7_INVARS_PAWSUSHAT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "diemixmag", Py_BuildValue("ii", AB7_INVARS_DIEMIXMAG, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "nsym", Py_BuildValue("ii", AB7_INVARS_NSYM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "berrystep", Py_BuildValue("ii", AB7_INVARS_BERRYSTEP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irandom", Py_BuildValue("ii", AB7_INVARS_IRANDOM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "rfuser", Py_BuildValue("ii", AB7_INVARS_RFUSER, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtphdos", Py_BuildValue("ii", AB7_INVARS_PRTPHDOS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtcif", Py_BuildValue("ii", AB7_INVARS_PRTCIF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmatpawu", Py_BuildValue("ii", AB7_INVARS_DMATPAWU, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "plowan_bandf", Py_BuildValue("ii", AB7_INVARS_PLOWAN_BANDF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtfsurf", Py_BuildValue("ii", AB7_INVARS_PRTFSURF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "accuracy", Py_BuildValue("ii", AB7_INVARS_ACCURACY, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "npband", Py_BuildValue("ii", AB7_INVARS_NPBAND, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert2_elfd", Py_BuildValue("ii", AB7_INVARS_D3E_PERT2_ELFD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getbsreso", Py_BuildValue("ii", AB7_INVARS_GETBSRESO, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_kmax_numeric", Py_BuildValue("ii", AB7_INVARS_GWLS_KMAX_NUMERIC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ixc_sigma", Py_BuildValue("ii", AB7_INVARS_IXC_SIGMA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nfft", Py_BuildValue("ii", AB7_INVARS_NFFT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "rfasr", Py_BuildValue("ii", AB7_INVARS_RFASR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "qptrlatt", Py_BuildValue("ii", AB7_INVARS_QPTRLATT, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "fftgw", Py_BuildValue("ii", AB7_INVARS_FFTGW, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "neb_spring", Py_BuildValue("ii", AB7_INVARS_NEB_SPRING, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "plowan_nt", Py_BuildValue("ii", AB7_INVARS_PLOWAN_NT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "rfelfd", Py_BuildValue("ii", AB7_INVARS_RFELFD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtvhxc", Py_BuildValue("ii", AB7_INVARS_PRTVHXC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mbpt_sciss", Py_BuildValue("ii", AB7_INVARS_MBPT_SCISS, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "mgfft", Py_BuildValue("ii", AB7_INVARS_MGFFT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmatudiag", Py_BuildValue("ii", AB7_INVARS_DMATUDIAG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "recgratio", Py_BuildValue("ii", AB7_INVARS_RECGRATIO, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mdwall", Py_BuildValue("ii", AB7_INVARS_MDWALL, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "getpawden", Py_BuildValue("ii", AB7_INVARS_GETPAWDEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_qratio", Py_BuildValue("ii", AB7_INVARS_VDW_DF_QRATIO, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "plowan_projcalc", Py_BuildValue("ii", AB7_INVARS_PLOWAN_PROJCALC, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "npwkss", Py_BuildValue("ii", AB7_INVARS_NPWKSS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "friction", Py_BuildValue("ii", AB7_INVARS_FRICTION, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_exchange", Py_BuildValue("ii", AB7_INVARS_GWLS_EXCHANGE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gw_nqlwl", Py_BuildValue("ii", AB7_INVARS_GW_NQLWL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwcalctyp", Py_BuildValue("ii", AB7_INVARS_GWCALCTYP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_hayd_term", Py_BuildValue("ii", AB7_INVARS_BS_HAYD_TERM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdsuscep", Py_BuildValue("ii", AB7_INVARS_IRDSUSCEP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_interp_method", Py_BuildValue("ii", AB7_INVARS_BS_INTERP_METHOD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "zeemanfield", Py_BuildValue("ii", AB7_INVARS_ZEEMANFIELD, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "focktoldfe", Py_BuildValue("ii", AB7_INVARS_FOCKTOLDFE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "chkprim", Py_BuildValue("ii", AB7_INVARS_CHKPRIM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nqpt", Py_BuildValue("ii", AB7_INVARS_NQPT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dosdeltae", Py_BuildValue("ii", AB7_INVARS_DOSDELTAE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "prtefg", Py_BuildValue("ii", AB7_INVARS_PRTEFG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtkbff", Py_BuildValue("ii", AB7_INVARS_PRTKBFF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdvdw", Py_BuildValue("ii", AB7_INVARS_IRDVDW, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "kptrlen", Py_BuildValue("ii", AB7_INVARS_KPTRLEN, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "kptgw", Py_BuildValue("ii", AB7_INVARS_KPTGW, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "bs_coupling", Py_BuildValue("ii", AB7_INVARS_BS_COUPLING, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdefmas", Py_BuildValue("ii", AB7_INVARS_IRDEFMAS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tolrde", Py_BuildValue("ii", AB7_INVARS_TOLRDE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "getvel", Py_BuildValue("ii", AB7_INVARS_GETVEL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmftbandf", Py_BuildValue("ii", AB7_INVARS_DMFTBANDF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bdgw", Py_BuildValue("ii", AB7_INVARS_BDGW, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "dmft_read_occnd", Py_BuildValue("ii", AB7_INVARS_DMFT_READ_OCCND, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawxcdev", Py_BuildValue("ii", AB7_INVARS_PAWXCDEV, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "esmear", Py_BuildValue("ii", AB7_INVARS_ESMEAR, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ph_nqshift", Py_BuildValue("ii", AB7_INVARS_PH_NQSHIFT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmftcheck", Py_BuildValue("ii", AB7_INVARS_DMFTCHECK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtwf", Py_BuildValue("ii", AB7_INVARS_PRTWF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "kptbounds", Py_BuildValue("ii", AB7_INVARS_KPTBOUNDS, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "mem_test", Py_BuildValue("ii", AB7_INVARS_MEM_TEST, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_gcut", Py_BuildValue("ii", AB7_INVARS_VDW_DF_GCUT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "irdddb", Py_BuildValue("ii", AB7_INVARS_IRDDDB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "kptns_hf", Py_BuildValue("ii", AB7_INVARS_KPTNS_HF, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "gwcomp", Py_BuildValue("ii", AB7_INVARS_GWCOMP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawujv", Py_BuildValue("ii", AB7_INVARS_PAWUJV, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "mqgriddg", Py_BuildValue("ii", AB7_INVARS_MQGRIDDG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_nstates", Py_BuildValue("ii", AB7_INVARS_BS_NSTATES, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ndynimage", Py_BuildValue("ii", AB7_INVARS_NDYNIMAGE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "amu_orig", Py_BuildValue("ii", AB7_INVARS_AMU_ORIG, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "gwls_nseeds", Py_BuildValue("ii", AB7_INVARS_GWLS_NSEEDS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "qptn", Py_BuildValue("ii", AB7_INVARS_QPTN, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "tl_nprccg", Py_BuildValue("ii", AB7_INVARS_TL_NPRCCG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bfield", Py_BuildValue("ii", AB7_INVARS_BFIELD, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "pawprtwf", Py_BuildValue("ii", AB7_INVARS_PAWPRTWF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "strfact", Py_BuildValue("ii", AB7_INVARS_STRFACT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "userrb", Py_BuildValue("ii", AB7_INVARS_USERRB, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "chneut", Py_BuildValue("ii", AB7_INVARS_CHNEUT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "symdynmat", Py_BuildValue("ii", AB7_INVARS_SYMDYNMAT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ird1wf", Py_BuildValue("ii", AB7_INVARS_IRD1WF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_print_debug", Py_BuildValue("ii", AB7_INVARS_GWLS_PRINT_DEBUG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nelect", Py_BuildValue("ii", AB7_INVARS_NELECT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_dsoft", Py_BuildValue("ii", AB7_INVARS_VDW_DF_DSOFT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "positron", Py_BuildValue("ii", AB7_INVARS_POSITRON, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dielng", Py_BuildValue("ii", AB7_INVARS_DIELNG, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ngkpt", Py_BuildValue("ii", AB7_INVARS_NGKPT, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "chkdilatmx", Py_BuildValue("ii", AB7_INVARS_CHKDILATMX, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "jpawu", Py_BuildValue("ii", AB7_INVARS_JPAWU, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "omegasimax", Py_BuildValue("ii", AB7_INVARS_OMEGASIMAX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "pawlmix", Py_BuildValue("ii", AB7_INVARS_PAWLMIX, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtlden", Py_BuildValue("ii", AB7_INVARS_PRTLDEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "optstress", Py_BuildValue("ii", AB7_INVARS_OPTSTRESS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "wtq", Py_BuildValue("ii", AB7_INVARS_WTQ, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "rfddk", Py_BuildValue("ii", AB7_INVARS_RFDDK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_stern_kmax", Py_BuildValue("ii", AB7_INVARS_GWLS_STERN_KMAX, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtatlist", Py_BuildValue("ii", AB7_INVARS_PRTATLIST, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "prtphsurf", Py_BuildValue("ii", AB7_INVARS_PRTPHSURF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ga_rules", Py_BuildValue("ii", AB7_INVARS_GA_RULES, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "wtatcon", Py_BuildValue("ii", AB7_INVARS_WTATCON, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "getefmas", Py_BuildValue("ii", AB7_INVARS_GETEFMAS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "usepaw", Py_BuildValue("ii", AB7_INVARS_USEPAW, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "smdelta", Py_BuildValue("ii", AB7_INVARS_SMDELTA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawujrad", Py_BuildValue("ii", AB7_INVARS_PAWUJRAD, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "bandpp", Py_BuildValue("ii", AB7_INVARS_BANDPP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmftctqmc_basis", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_BASIS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ldaminushalf", Py_BuildValue("ii", AB7_INVARS_LDAMINUSHALF, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "getwfk", Py_BuildValue("ii", AB7_INVARS_GETWFK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "diismemory", Py_BuildValue("ii", AB7_INVARS_DIISMEMORY, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getwfq", Py_BuildValue("ii", AB7_INVARS_GETWFQ, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "fband", Py_BuildValue("ii", AB7_INVARS_FBAND, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "magcon_lambda", Py_BuildValue("ii", AB7_INVARS_MAGCON_LAMBDA, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "natsph_extra", Py_BuildValue("ii", AB7_INVARS_NATSPH_EXTRA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nbandkss", Py_BuildValue("ii", AB7_INVARS_NBANDKSS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "freqspmax", Py_BuildValue("ii", AB7_INVARS_FREQSPMAX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "tl_radius", Py_BuildValue("ii", AB7_INVARS_TL_RADIUS, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "gw_sigxcore", Py_BuildValue("ii", AB7_INVARS_GW_SIGXCORE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pitransform", Py_BuildValue("ii", AB7_INVARS_PITRANSFORM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "diegap", Py_BuildValue("ii", AB7_INVARS_DIEGAP, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ziontypat", Py_BuildValue("ii", AB7_INVARS_ZIONTYPAT, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "pawmixdg", Py_BuildValue("ii", AB7_INVARS_PAWMIXDG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "strprecon", Py_BuildValue("ii", AB7_INVARS_STRPRECON, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "prtdipole", Py_BuildValue("ii", AB7_INVARS_PRTDIPOLE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pol", Py_BuildValue("ii", AB7_INVARS_POL, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "dmftctqmc_mov", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_MOV, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "istatshft", Py_BuildValue("ii", AB7_INVARS_ISTATSHFT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "npweps", Py_BuildValue("ii", AB7_INVARS_NPWEPS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "spnorbscl", Py_BuildValue("ii", AB7_INVARS_SPNORBSCL, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ga_algor", Py_BuildValue("ii", AB7_INVARS_GA_ALGOR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "wtk", Py_BuildValue("ii", AB7_INVARS_WTK, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "ga_n_rules", Py_BuildValue("ii", AB7_INVARS_GA_N_RULES, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ecutwfn", Py_BuildValue("ii", AB7_INVARS_ECUTWFN, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_recycle", Py_BuildValue("ii", AB7_INVARS_GWLS_RECYCLE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "awtr", Py_BuildValue("ii", AB7_INVARS_AWTR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_acutmin", Py_BuildValue("ii", AB7_INVARS_VDW_DF_ACUTMIN, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "nkptgw", Py_BuildValue("ii", AB7_INVARS_NKPTGW, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "occ_orig", Py_BuildValue("ii", AB7_INVARS_OCC_ORIG, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "npulayit", Py_BuildValue("ii", AB7_INVARS_NPULAYIT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmft_nwli", Py_BuildValue("ii", AB7_INVARS_DMFT_NWLI, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ratsph_extra", Py_BuildValue("ii", AB7_INVARS_RATSPH_EXTRA, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "inclvkb", Py_BuildValue("ii", AB7_INVARS_INCLVKB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nnos", Py_BuildValue("ii", AB7_INVARS_NNOS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "efmas_dim", Py_BuildValue("ii", AB7_INVARS_EFMAS_DIM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwrpacorr", Py_BuildValue("ii", AB7_INVARS_GWRPACORR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dilatmx", Py_BuildValue("ii", AB7_INVARS_DILATMX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "dmatpuopt", Py_BuildValue("ii", AB7_INVARS_DMATPUOPT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawecutdg", Py_BuildValue("ii", AB7_INVARS_PAWECUTDG, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_kmax_complement", Py_BuildValue("ii", AB7_INVARS_GWLS_KMAX_COMPLEMENT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tolimg", Py_BuildValue("ii", AB7_INVARS_TOLIMG, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "wvl_bigdft_comp", Py_BuildValue("ii", AB7_INVARS_WVL_BIGDFT_COMP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmft_tolfreq", Py_BuildValue("ii", AB7_INVARS_DMFT_TOLFREQ, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "natvshift", Py_BuildValue("ii", AB7_INVARS_NATVSHIFT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_supercell", Py_BuildValue("ii", AB7_INVARS_VDW_SUPERCELL, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "acell_orig", Py_BuildValue("ii", AB7_INVARS_ACELL_ORIG, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "dmftctqmc_order", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_ORDER, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "diemac", Py_BuildValue("ii", AB7_INVARS_DIEMAC, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "efmas_deg_tol", Py_BuildValue("ii", AB7_INVARS_EFMAS_DEG_TOL, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "signperm", Py_BuildValue("ii", AB7_INVARS_SIGNPERM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bravais", Py_BuildValue("ii", AB7_INVARS_BRAVAIS, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "efmas", Py_BuildValue("ii", AB7_INVARS_EFMAS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_phisoft", Py_BuildValue("ii", AB7_INVARS_VDW_DF_PHISOFT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "prtgden", Py_BuildValue("ii", AB7_INVARS_PRTGDEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtstm", Py_BuildValue("ii", AB7_INVARS_PRTSTM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtfc", Py_BuildValue("ii", AB7_INVARS_PRTFC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "berryopt", Py_BuildValue("ii", AB7_INVARS_BERRYOPT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtvdw", Py_BuildValue("ii", AB7_INVARS_PRTVDW, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ixcpositron", Py_BuildValue("ii", AB7_INVARS_IXCPOSITRON, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getqps", Py_BuildValue("ii", AB7_INVARS_GETQPS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ndivsm", Py_BuildValue("ii", AB7_INVARS_NDIVSM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "timopt", Py_BuildValue("ii", AB7_INVARS_TIMOPT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_list_proj_freq", Py_BuildValue("ii", AB7_INVARS_GWLS_LIST_PROJ_FREQ, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "rfdir", Py_BuildValue("ii", AB7_INVARS_RFDIR, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "shiftk", Py_BuildValue("ii", AB7_INVARS_SHIFTK, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "ph_freez_disp_nampl", Py_BuildValue("ii", AB7_INVARS_PH_FREEZ_DISP_NAMPL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "kberry", Py_BuildValue("ii", AB7_INVARS_KBERRY, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "kptopt", Py_BuildValue("ii", AB7_INVARS_KPTOPT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nspden", Py_BuildValue("ii", AB7_INVARS_NSPDEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert1_atpol", Py_BuildValue("ii", AB7_INVARS_D3E_PERT1_ATPOL, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "bs_loband", Py_BuildValue("ii", AB7_INVARS_BS_LOBAND, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "usewvl", Py_BuildValue("ii", AB7_INVARS_USEWVL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getocc", Py_BuildValue("ii", AB7_INVARS_GETOCC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtposcar", Py_BuildValue("ii", AB7_INVARS_PRTPOSCAR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ph_intmeth", Py_BuildValue("ii", AB7_INVARS_PH_INTMETH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_correlation", Py_BuildValue("ii", AB7_INVARS_GWLS_CORRELATION, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nomegasrd", Py_BuildValue("ii", AB7_INVARS_NOMEGASRD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_nqpts", Py_BuildValue("ii", AB7_INVARS_VDW_DF_NQPTS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "iboxcut", Py_BuildValue("ii", AB7_INVARS_IBOXCUT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "paral_atom", Py_BuildValue("ii", AB7_INVARS_PARAL_ATOM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawntheta", Py_BuildValue("ii", AB7_INVARS_PAWNTHETA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmft_t2g", Py_BuildValue("ii", AB7_INVARS_DMFT_T2G, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "usedmft", Py_BuildValue("ii", AB7_INVARS_USEDMFT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ucrpa_window", Py_BuildValue("ii", AB7_INVARS_UCRPA_WINDOW, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "nshiftk", Py_BuildValue("ii", AB7_INVARS_NSHIFTK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtelf", Py_BuildValue("ii", AB7_INVARS_PRTELF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_rcut", Py_BuildValue("ii", AB7_INVARS_VDW_DF_RCUT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "gpu_linalg_limit", Py_BuildValue("ii", AB7_INVARS_GPU_LINALG_LIMIT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawfatbnd", Py_BuildValue("ii", AB7_INVARS_PAWFATBND, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "omegasrdmax", Py_BuildValue("ii", AB7_INVARS_OMEGASRDMAX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "natrd", Py_BuildValue("ii", AB7_INVARS_NATRD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "usepead", Py_BuildValue("ii", AB7_INVARS_USEPEAD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "noseinert", Py_BuildValue("ii", AB7_INVARS_NOSEINERT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "wvl_ngauss", Py_BuildValue("ii", AB7_INVARS_WVL_NGAUSS, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "intxc", Py_BuildValue("ii", AB7_INVARS_INTXC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "usexcnhat_orig", Py_BuildValue("ii", AB7_INVARS_USEXCNHAT_ORIG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mixesimgf", Py_BuildValue("ii", AB7_INVARS_MIXESIMGF, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "ixcrot", Py_BuildValue("ii", AB7_INVARS_IXCROT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ph_", Py_BuildValue("ii", AB7_INVARS_PH_, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getdelfd", Py_BuildValue("ii", AB7_INVARS_GETDELFD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "spgaxor", Py_BuildValue("ii", AB7_INVARS_SPGAXOR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dfpt_sciss", Py_BuildValue("ii", AB7_INVARS_DFPT_SCISS, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "get1den", Py_BuildValue("ii", AB7_INVARS_GET1DEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawspnorb", Py_BuildValue("ii", AB7_INVARS_PAWSPNORB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmftbandi", Py_BuildValue("ii", AB7_INVARS_DMFTBANDI, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nnsclo", Py_BuildValue("ii", AB7_INVARS_NNSCLO, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "rfmagn", Py_BuildValue("ii", AB7_INVARS_RFMAGN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdqps", Py_BuildValue("ii", AB7_INVARS_IRDQPS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nomegasi", Py_BuildValue("ii", AB7_INVARS_NOMEGASI, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "optnlxccc", Py_BuildValue("ii", AB7_INVARS_OPTNLXCCC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "diecut", Py_BuildValue("ii", AB7_INVARS_DIECUT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "eph_fsewin", Py_BuildValue("ii", AB7_INVARS_EPH_FSEWIN, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "jellslab", Py_BuildValue("ii", AB7_INVARS_JELLSLAB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ppmodel", Py_BuildValue("ii", AB7_INVARS_PPMODEL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawoptmix", Py_BuildValue("ii", AB7_INVARS_PAWOPTMIX, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "optcell", Py_BuildValue("ii", AB7_INVARS_OPTCELL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawprtdos", Py_BuildValue("ii", AB7_INVARS_PAWPRTDOS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mdf_epsinf", Py_BuildValue("ii", AB7_INVARS_MDF_EPSINF, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "cd_subset_freq", Py_BuildValue("ii", AB7_INVARS_CD_SUBSET_FREQ, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "berrysav", Py_BuildValue("ii", AB7_INVARS_BERRYSAV, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tolwfr", Py_BuildValue("ii", AB7_INVARS_TOLWFR, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ph_smear", Py_BuildValue("ii", AB7_INVARS_PH_SMEAR, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "prtvolimg", Py_BuildValue("ii", AB7_INVARS_PRTVOLIMG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "lotf_classic", Py_BuildValue("ii", AB7_INVARS_LOTF_CLASSIC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawnhatxc", Py_BuildValue("ii", AB7_INVARS_PAWNHATXC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ionmov", Py_BuildValue("ii", AB7_INVARS_IONMOV, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "strtarget", Py_BuildValue("ii", AB7_INVARS_STRTARGET, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "vdw_df_dratio", Py_BuildValue("ii", AB7_INVARS_VDW_DF_DRATIO, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "lotf_nitex", Py_BuildValue("ii", AB7_INVARS_LOTF_NITEX, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "w90iniprj", Py_BuildValue("ii", AB7_INVARS_W90INIPRJ, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nsppol", Py_BuildValue("ii", AB7_INVARS_NSPPOL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "hmctt", Py_BuildValue("ii", AB7_INVARS_HMCTT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_coulomb_term", Py_BuildValue("ii", AB7_INVARS_BS_COULOMB_TERM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nbandhf", Py_BuildValue("ii", AB7_INVARS_NBANDHF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ptgroupma", Py_BuildValue("ii", AB7_INVARS_PTGROUPMA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "hyb_range_dft", Py_BuildValue("ii", AB7_INVARS_HYB_RANGE_DFT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "hmcsst", Py_BuildValue("ii", AB7_INVARS_HMCSST, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tphysel", Py_BuildValue("ii", AB7_INVARS_TPHYSEL, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "symrel", Py_BuildValue("ii", AB7_INVARS_SYMREL, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "pawcpxocc", Py_BuildValue("ii", AB7_INVARS_PAWCPXOCC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "wvl_frmult", Py_BuildValue("ii", AB7_INVARS_WVL_FRMULT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "bs_interp_prep", Py_BuildValue("ii", AB7_INVARS_BS_INTERP_PREP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawusecp", Py_BuildValue("ii", AB7_INVARS_PAWUSECP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ph_freez_disp_ampl", Py_BuildValue("ii", AB7_INVARS_PH_FREEZ_DISP_AMPL, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "userib", Py_BuildValue("ii", AB7_INVARS_USERIB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "rf2_dkdk", Py_BuildValue("ii", AB7_INVARS_RF2_DKDK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "so_psp", Py_BuildValue("ii", AB7_INVARS_SO_PSP, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "prtpot", Py_BuildValue("ii", AB7_INVARS_PRTPOT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "plowan_realspace", Py_BuildValue("ii", AB7_INVARS_PLOWAN_REALSPACE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "rf2_dkde", Py_BuildValue("ii", AB7_INVARS_RF2_DKDE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dipdip", Py_BuildValue("ii", AB7_INVARS_DIPDIP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "optforces", Py_BuildValue("ii", AB7_INVARS_OPTFORCES, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "brvltt", Py_BuildValue("ii", AB7_INVARS_BRVLTT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert1_phon", Py_BuildValue("ii", AB7_INVARS_D3E_PERT1_PHON, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "boxcutmin", Py_BuildValue("ii", AB7_INVARS_BOXCUTMIN, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ntime", Py_BuildValue("ii", AB7_INVARS_NTIME, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtvha", Py_BuildValue("ii", AB7_INVARS_PRTVHA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "npsp", Py_BuildValue("ii", AB7_INVARS_NPSP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "spbroad", Py_BuildValue("ii", AB7_INVARS_SPBROAD, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "goprecprm", Py_BuildValue("ii", AB7_INVARS_GOPRECPRM, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "prtvol", Py_BuildValue("ii", AB7_INVARS_PRTVOL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nqptdm", Py_BuildValue("ii", AB7_INVARS_NQPTDM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtbltztrp", Py_BuildValue("ii", AB7_INVARS_PRTBLTZTRP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "densfor_pred", Py_BuildValue("ii", AB7_INVARS_DENSFOR_PRED, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "isecur", Py_BuildValue("ii", AB7_INVARS_ISECUR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "rhoqpmix", Py_BuildValue("ii", AB7_INVARS_RHOQPMIX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "natsph", Py_BuildValue("ii", AB7_INVARS_NATSPH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getbscoup", Py_BuildValue("ii", AB7_INVARS_GETBSCOUP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmft_nlambda", Py_BuildValue("ii", AB7_INVARS_DMFT_NLAMBDA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pimd_constraint", Py_BuildValue("ii", AB7_INVARS_PIMD_CONSTRAINT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nwfshist", Py_BuildValue("ii", AB7_INVARS_NWFSHIST, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "freqspmin", Py_BuildValue("ii", AB7_INVARS_FREQSPMIN, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ecut", Py_BuildValue("ii", AB7_INVARS_ECUT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "pawprt_k", Py_BuildValue("ii", AB7_INVARS_PAWPRT_K, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawoptosc", Py_BuildValue("ii", AB7_INVARS_PAWOPTOSC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nkpt", Py_BuildValue("ii", AB7_INVARS_NKPT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "random_atpos", Py_BuildValue("ii", AB7_INVARS_RANDOM_ATPOS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawprt_b", Py_BuildValue("ii", AB7_INVARS_PAWPRT_B, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nconeq", Py_BuildValue("ii", AB7_INVARS_NCONEQ, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "rprim_orig", Py_BuildValue("ii", AB7_INVARS_RPRIM_ORIG, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "efmas_bands", Py_BuildValue("ii", AB7_INVARS_EFMAS_BANDS, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "vdw_xc", Py_BuildValue("ii", AB7_INVARS_VDW_XC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ieig2rf", Py_BuildValue("ii", AB7_INVARS_IEIG2RF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "use_nonscf_gkk", Py_BuildValue("ii", AB7_INVARS_USE_NONSCF_GKK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_interp_mode", Py_BuildValue("ii", AB7_INVARS_BS_INTERP_MODE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_eh_cutoff", Py_BuildValue("ii", AB7_INVARS_BS_EH_CUTOFF, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "getsuscep", Py_BuildValue("ii", AB7_INVARS_GETSUSCEP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "wfk_task", Py_BuildValue("ii", AB7_INVARS_WFK_TASK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gwls_n_proj_freq", Py_BuildValue("ii", AB7_INVARS_GWLS_N_PROJ_FREQ, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "natom", Py_BuildValue("ii", AB7_INVARS_NATOM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_ndpts", Py_BuildValue("ii", AB7_INVARS_VDW_DF_NDPTS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtdos", Py_BuildValue("ii", AB7_INVARS_PRTDOS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "spgorig", Py_BuildValue("ii", AB7_INVARS_SPGORIG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nucdipmom", Py_BuildValue("ii", AB7_INVARS_NUCDIPMOM, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "d3e_pert1_dir", Py_BuildValue("ii", AB7_INVARS_D3E_PERT1_DIR, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "eph_intmeth", Py_BuildValue("ii", AB7_INVARS_EPH_INTMETH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "spinat", Py_BuildValue("ii", AB7_INVARS_SPINAT, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "xredsph_extra", Py_BuildValue("ii", AB7_INVARS_XREDSPH_EXTRA, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "nnsclohf", Py_BuildValue("ii", AB7_INVARS_NNSCLOHF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "symmorphi", Py_BuildValue("ii", AB7_INVARS_SYMMORPHI, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "cd_customnimfrqs", Py_BuildValue("ii", AB7_INVARS_CD_CUSTOMNIMFRQS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "fermie_nest", Py_BuildValue("ii", AB7_INVARS_FERMIE_NEST, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "bs_haydock_tol", Py_BuildValue("ii", AB7_INVARS_BS_HAYDOCK_TOL, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "npspalch", Py_BuildValue("ii", AB7_INVARS_NPSPALCH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "auxc_ixc", Py_BuildValue("ii", AB7_INVARS_AUXC_IXC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert2_atpol", Py_BuildValue("ii", AB7_INVARS_D3E_PERT2_ATPOL, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "znucl", Py_BuildValue("ii", AB7_INVARS_ZNUCL, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "pawnzlm", Py_BuildValue("ii", AB7_INVARS_PAWNZLM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "nfreqim", Py_BuildValue("ii", AB7_INVARS_NFREQIM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmft_nwlo", Py_BuildValue("ii", AB7_INVARS_DMFT_NWLO, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "upawu", Py_BuildValue("ii", AB7_INVARS_UPAWU, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "prtwant", Py_BuildValue("ii", AB7_INVARS_PRTWANT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mband", Py_BuildValue("ii", AB7_INVARS_MBAND, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getscr", Py_BuildValue("ii", AB7_INVARS_GETSCR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtkden", Py_BuildValue("ii", AB7_INVARS_PRTKDEN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "optdriver", Py_BuildValue("ii", AB7_INVARS_OPTDRIVER, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_damax", Py_BuildValue("ii", AB7_INVARS_VDW_DF_DAMAX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "nshiftk_orig", Py_BuildValue("ii", AB7_INVARS_NSHIFTK_ORIG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gw_qprange", Py_BuildValue("ii", AB7_INVARS_GW_QPRANGE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "qptopt", Py_BuildValue("ii", AB7_INVARS_QPTOPT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "chkexit", Py_BuildValue("ii", AB7_INVARS_CHKEXIT, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "eph_fermie", Py_BuildValue("ii", AB7_INVARS_EPH_FERMIE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "prtbbb", Py_BuildValue("ii", AB7_INVARS_PRTBBB, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ph_qshift", Py_BuildValue("ii", AB7_INVARS_PH_QSHIFT, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "red_dfield", Py_BuildValue("ii", AB7_INVARS_RED_DFIELD, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "nkpthf", Py_BuildValue("ii", AB7_INVARS_NKPTHF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dtion", Py_BuildValue("ii", AB7_INVARS_DTION, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ph_qpath", Py_BuildValue("ii", AB7_INVARS_PH_QPATH, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "vdw_df_aratio", Py_BuildValue("ii", AB7_INVARS_VDW_DF_ARATIO, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "prteig", Py_BuildValue("ii", AB7_INVARS_PRTEIG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vacnum", Py_BuildValue("ii", AB7_INVARS_VACNUM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert3_dir", Py_BuildValue("ii", AB7_INVARS_D3E_PERT3_DIR, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "goprecon", Py_BuildValue("ii", AB7_INVARS_GOPRECON, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "istwfk", Py_BuildValue("ii", AB7_INVARS_ISTWFK, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "mixalch_orig", Py_BuildValue("ii", AB7_INVARS_MIXALCH_ORIG, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "prtgkk", Py_BuildValue("ii", AB7_INVARS_PRTGKK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "quadmom", Py_BuildValue("ii", AB7_INVARS_QUADMOM, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "shiftk_orig", Py_BuildValue("ii", AB7_INVARS_SHIFTK_ORIG, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "ortalg", Py_BuildValue("ii", AB7_INVARS_ORTALG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "pawprtvol", Py_BuildValue("ii", AB7_INVARS_PAWPRTVOL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tolvrs", Py_BuildValue("ii", AB7_INVARS_TOLVRS, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "magconon", Py_BuildValue("ii", AB7_INVARS_MAGCONON, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "f6of2_sla", Py_BuildValue("ii", AB7_INVARS_F6OF2_SLA, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "wfmix", Py_BuildValue("ii", AB7_INVARS_WFMIX, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "neb_algo", Py_BuildValue("ii", AB7_INVARS_NEB_ALGO, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "posdoppler", Py_BuildValue("ii", AB7_INVARS_POSDOPPLER, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtfull1wf", Py_BuildValue("ii", AB7_INVARS_PRTFULL1WF, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ph_freez_disp_addstrain", Py_BuildValue("ii", AB7_INVARS_PH_FREEZ_DISP_ADDSTRAIN, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_interp_m3_width", Py_BuildValue("ii", AB7_INVARS_BS_INTERP_M3_WIDTH, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "recnrec", Py_BuildValue("ii", AB7_INVARS_RECNREC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "tsmear", Py_BuildValue("ii", AB7_INVARS_TSMEAR, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "kptrlatt_orig", Py_BuildValue("ii", AB7_INVARS_KPTRLATT_ORIG, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "cd_full_grid", Py_BuildValue("ii", AB7_INVARS_CD_FULL_GRID, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "bs_calctype", Py_BuildValue("ii", AB7_INVARS_BS_CALCTYPE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "posnstep", Py_BuildValue("ii", AB7_INVARS_POSNSTEP, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "irdhaydock", Py_BuildValue("ii", AB7_INVARS_IRDHAYDOCK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "fxcartfactor", Py_BuildValue("ii", AB7_INVARS_FXCARTFACTOR, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "recnpath", Py_BuildValue("ii", AB7_INVARS_RECNPATH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "elph2_imagden", Py_BuildValue("ii", AB7_INVARS_ELPH2_IMAGDEN, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "nkpath", Py_BuildValue("ii", AB7_INVARS_NKPATH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "gw_frqre_tangrid", Py_BuildValue("ii", AB7_INVARS_GW_FRQRE_TANGRID, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "plowan_nbl", Py_BuildValue("ii", AB7_INVARS_PLOWAN_NBL, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "eshift", Py_BuildValue("ii", AB7_INVARS_ESHIFT, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "adpimd_gamma", Py_BuildValue("ii", AB7_INVARS_ADPIMD_GAMMA, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "istatr", Py_BuildValue("ii", AB7_INVARS_ISTATR, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_zab", Py_BuildValue("ii", AB7_INVARS_VDW_DF_ZAB, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "pawnphi", Py_BuildValue("ii", AB7_INVARS_PAWNPHI, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "d3e_pert1_elfd", Py_BuildValue("ii", AB7_INVARS_D3E_PERT1_ELFD, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "lpawu", Py_BuildValue("ii", AB7_INVARS_LPAWU, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "xclevel", Py_BuildValue("ii", AB7_INVARS_XCLEVEL, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "fockoptmix", Py_BuildValue("ii", AB7_INVARS_FOCKOPTMIX, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ntyppure", Py_BuildValue("ii", AB7_INVARS_NTYPPURE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "mqgrid", Py_BuildValue("ii", AB7_INVARS_MQGRID, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ddb_shiftq", Py_BuildValue("ii", AB7_INVARS_DDB_SHIFTQ, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "ucrpa_bands", Py_BuildValue("ii", AB7_INVARS_UCRPA_BANDS, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "plowan_natom", Py_BuildValue("ii", AB7_INVARS_PLOWAN_NATOM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "jfielddir", Py_BuildValue("ii", AB7_INVARS_JFIELDDIR, _INT_ARRAY));
  PyDict_SetItemString(DictIds, "tolrff", Py_BuildValue("ii", AB7_INVARS_TOLRFF, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ph_wstep", Py_BuildValue("ii", AB7_INVARS_PH_WSTEP, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "symsigma", Py_BuildValue("ii", AB7_INVARS_SYMSIGMA, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "posocc", Py_BuildValue("ii", AB7_INVARS_POSOCC, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "slabzend", Py_BuildValue("ii", AB7_INVARS_SLABZEND, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "pimass", Py_BuildValue("ii", AB7_INVARS_PIMASS, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "dmft_iter", Py_BuildValue("ii", AB7_INVARS_DMFT_ITER, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmft_dc", Py_BuildValue("ii", AB7_INVARS_DMFT_DC, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "f4of2_sla", Py_BuildValue("ii", AB7_INVARS_F4OF2_SLA, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "vel_cell_orig", Py_BuildValue("ii", AB7_INVARS_VEL_CELL_ORIG, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "hyb_mixing_sr", Py_BuildValue("ii", AB7_INVARS_HYB_MIXING_SR, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "ppmfrq", Py_BuildValue("ii", AB7_INVARS_PPMFRQ, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "tmesh", Py_BuildValue("ii", AB7_INVARS_TMESH, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "dmftctqmc_check", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_CHECK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "prtdensph", Py_BuildValue("ii", AB7_INVARS_PRTDENSPH, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vdw_df_nrpts", Py_BuildValue("ii", AB7_INVARS_VDW_DF_NRPTS, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "toldff", Py_BuildValue("ii", AB7_INVARS_TOLDFF, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "toldfe", Py_BuildValue("ii", AB7_INVARS_TOLDFE, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "prtgeo", Py_BuildValue("ii", AB7_INVARS_PRTGEO, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "vprtrb", Py_BuildValue("ii", AB7_INVARS_VPRTRB, _DOUBLE_ARRAY));
  PyDict_SetItemString(DictIds, "mkqmem", Py_BuildValue("ii", AB7_INVARS_MKQMEM, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "getdkde", Py_BuildValue("ii", AB7_INVARS_GETDKDE, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "stmbias", Py_BuildValue("ii", AB7_INVARS_STMBIAS, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "xc_denpos", Py_BuildValue("ii", AB7_INVARS_XC_DENPOS, _DOUBLE_SCALAR));
  PyDict_SetItemString(DictIds, "getdkdk", Py_BuildValue("ii", AB7_INVARS_GETDKDK, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "dmftctqmc_triqs_nleg", Py_BuildValue("ii", AB7_INVARS_DMFTCTQMC_TRIQS_NLEG, _INT_SCALAR));
  PyDict_SetItemString(DictIds, "ngfft", Py_BuildValue("ii", AB7_INVARS_NGFFT, _INT_ARRAY));
}
